/*-
 * Copyright (c) 2005, Kohsuke Ohtani
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of any co-contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <boot.h>
#include <platform.h>
#include "cyclone_boot.h"

extern uint32_t	ebsabootaddr;

/*
 * Setup boot information.
 */
void
setup_bootinfo(struct boot_info **bpp)
{
	struct boot_info *bp;
	struct ebsaboot *ebp;

	bp = (struct boot_info *)BOOT_INFO;
	memset(bp, 0, BOOT_INFO_SIZE);

	bp->archive = (u_long)ARCHIVE_START;

	bp->video.text_x = 30;
	bp->video.text_y = 20;

	ebp = (struct ebsaboot *)ebsabootaddr;
	if (ebp->bt_magic != BT_MAGIC_NUMBER_CATS &&
		ebp->bt_magic != BT_MAGIC_NUMBER_EBSA) {
		panic("Incorrect firmware signature");
	}

	bp->main_mem.start = ebp->bt_memstart + 0x00100000;
	bp->main_mem.size  = ebp->bt_memend - bp->main_mem.start;

	printk("%s%u firmware: physical memory @0x%x->0x%x (%u KB); bootarg \"%s\"; fclk: %uMHz, pciclk %uMHz;\n",
			ebp->bt_magic == BT_MAGIC_NUMBER_CATS ? "CATS" : "EBSA", ebp->bt_vers,
			ebp->bt_memstart, ebp->bt_memend, bp->main_mem.size / 1024,
			(char *)ebp->bt_args, ebp->bt_fclk / 1000000, ebp->bt_pciclk / 1000000);

	*bpp = bp;
}
